@@ -7,14 +7,16 @@ from werkzeug.utils import redirect
 
 from .app import Shimehari
 from .controllers import ApplicationController
-from .helpers import jsonAvailable, json, urlFor, jsonify, sendFile
+from .configuration import ConfigManager
+from .logging import createLogger
+from .helpers import jsonAvailable, json, urlFor, jsonify, sendFile, flash, getFlashedMessage
 from .routing import Router, Resource, RESTfulRule, Root, Group
 from .shared import request, session, shared, _requestContextStack, _appContextStack, currentApp
 from .template import renderTemplate, renderTempalteString
 from .wrappers import Request, Response
 from .cache import Cache
 
-VERSION = '0.1.7'
+VERSION = '0.1.8'
 AUTHOR = 'Yamaguchi Eikichi, Keiichiro Matsumoto'
 
 
