@@ -39,7 +39,7 @@ _loggerLock = Lock()
 
 def setupMethod(f):
     def wrapperFunc(self, *args, **kwargs):
-        if self.debug or self._gotFirstRequest:
+        if self.debug and self._gotFirstRequest:
             raise AssertionError('Setup seems to have already completed ...')
         return f(self, *args, **kwargs)
     return update_wrapper(wrapperFunc, f)
@@ -336,7 +336,8 @@ class Shimehari(_Kouzi):
             if hasattr(routerMod, 'appRoutes'):
                 self.router = routerMod.appRoutes
             if self.hasStaticFolder:
-                self.addRoute(self.staticURL + '/<path:filename>', self.sendStaticFile)
+                for url in self.getStaticURLs():
+                    self.addRoute(url + '/<path:filename>', self.sendStaticFile)
         except (ImportError, AttributeError), e:
             raise ShimehariSetupError('Failed to setup the router ...\n details::\n%s' % e)
 
@@ -617,7 +618,7 @@ class Shimehari(_Kouzi):
                 response = self.makeResponse(self.handleException(e))
             return response(environ, startResponse)
 
-    def drink(self, host=None, port=None, debug=None, **options):
+    def drink(self, host, port, debug=None, **options):
         u"""アプリを実行します。
 
         :param host:    ホスト名
@@ -626,10 +627,6 @@ class Shimehari(_Kouzi):
         :param options: kwargs
         """
         from werkzeug.serving import run_simple
-        if host is None:
-            host = '127.0.0.1'
-        if port is None:
-            port = 5959
         if debug is not None:
             self.debug = bool(debug)
         options.setdefault('use_reloader', self.debug)
